package com.bonus.canteen.core.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.device.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.device.domain.DeviceGlobalSetting;
import com.bonus.canteen.core.device.service.IDeviceGlobalSettingService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 设备参数Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "设备参数接口")
@RestController
@RequestMapping("/device_global_setting")
public class DeviceGlobalSettingController extends BaseController {
    @Autowired
    private IDeviceGlobalSettingService deviceGlobalSettingService;

    /**
     * 查询设备参数列表
     */
    @ApiOperation(value = "查询设备参数列表")
    //@RequiresPermissions("device:setting:list")
    @GetMapping("/list")
    public TableDataInfo list(DeviceGlobalSetting deviceGlobalSetting) {
        startPage();
        List<DeviceGlobalSetting> list = deviceGlobalSettingService.selectDeviceGlobalSettingList(deviceGlobalSetting);
        return getDataTable(list);
    }

    /**
     * 导出设备参数列表
     */
    @ApiOperation(value = "导出设备参数列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("device:setting:export")
    @SysLog(title = "设备参数", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出设备参数")
    @PostMapping("/export")
    public void export(HttpServletResponse response, DeviceGlobalSetting deviceGlobalSetting) {
        List<DeviceGlobalSetting> list = deviceGlobalSettingService.selectDeviceGlobalSettingList(deviceGlobalSetting);
        ExcelUtil<DeviceGlobalSetting> util = new ExcelUtil<DeviceGlobalSetting>(DeviceGlobalSetting.class);
        util.exportExcel(response, list, "设备参数数据");
    }

    /**
     * 获取设备参数详细信息
     */
    @ApiOperation(value = "获取设备参数详细信息")
    //@RequiresPermissions("device:setting:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(deviceGlobalSettingService.selectDeviceGlobalSettingById(id));
    }

    /**
     * 新增设备参数
     */
    @ApiOperation(value = "新增设备参数")
    //@PreventRepeatSubmit
    //@RequiresPermissions("device:setting:add")
    @SysLog(title = "设备参数", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增设备参数")
    @PostMapping
    public AjaxResult add(@RequestBody DeviceGlobalSetting deviceGlobalSetting) {
        try {
            return toAjax(deviceGlobalSettingService.insertDeviceGlobalSetting(deviceGlobalSetting));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改设备参数
     */
    @ApiOperation(value = "修改设备参数")
    //@PreventRepeatSubmit
    //@RequiresPermissions("device:setting:edit")
    @SysLog(title = "设备参数", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改设备参数")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody DeviceGlobalSetting deviceGlobalSetting) {
        try {
            return toAjax(deviceGlobalSettingService.updateDeviceGlobalSetting(deviceGlobalSetting));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除设备参数
     */
    @ApiOperation(value = "删除设备参数")
    //@PreventRepeatSubmit
    //@RequiresPermissions("device:setting:remove")
    @SysLog(title = "设备参数", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除设备参数")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(deviceGlobalSettingService.deleteDeviceGlobalSettingByIds(ids));
    }
}
